==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>Geen begrenzing geselecteerd</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>Loop niet gesloten op punt %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>Elk rand objekt moet een lijn, boog, cirkel, ellips boog, ellips, polylijn of spline zijn. Gevonden:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Arcering</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>Teken arceringen of inkleuringen</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Arcering</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Inkleuring</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Arceer patroon</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Patroon</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Hoek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Schaal:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">Geen begrenzing geselecteerd</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">Loop niet gesloten op punt %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">Elk rand objekt moet een lijn, boog, cirkel, ellips boog, ellips, polylijn of spline zijn. Gevonden:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Arcering gereedschappen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Toon arcering gereedschappen</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>&amp;Arcering</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">Teken arceringen of inkleuringen</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Arcering</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Inkleuring</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Arceer patroon</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Patroon</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Hoek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Schaal:</translation>
    </message>
</context>
</TS>
